#
# spec file for package bspwm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Luke Jones, luke.nukem.jones@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bspwm
Version:        0.9.2
Release:        4.2
Summary:        A tiling window manager based on binary space partitioning
License:        BSD-2-Clause
Group:          System/GUI/Other
Url:            https://github.com/baskerville/bspwm
Source0:        https://github.com/baskerville/bspwm/archive/%{version}.tar.gz
Source1:        bspwm.desktop
BuildRequires:  pkgconfig
BuildRequires:  zsh
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-event)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-xkb)
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
Recommends:     dmenu
Recommends:     lemonbar
Recommends:     sxhkd

%description
A tiling window manager based on binary space partitioning.
* It only responds to X events, and the messages it receives on a dedicated socket.
* bspc is a program that writes messages on bspwm's socket.
* bspwm doesn't handle any keyboard or pointer inputs: a third party program (e.g.
sxhkd) is needed in order to translate keyboard and pointer events to bspc invocations.

%prep
%setup -q

%build
install -pm 644 %{SOURCE1} contrib/freedesktop/bspwm.desktop
make %{?_smp_mflags} V=1

%install
%make_install PREFIX=%{_prefix} DOCPREFIX=%{_docdir}/%{name} MANPREFIX=%{_mandir}
install -D -p -m 644 examples/bspwmrc \
        %{buildroot}%{_sysconfdir}/skel/.config/bspwm/bspwmrc
install -D -p -m 644 LICENSE %{buildroot}%{_docdir}/%{name}/LICENSE

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr (-, root, root)
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_bindir}/bspwm
%{_bindir}/bspc
%{_docdir}/%{name}
%{_mandir}/man1/bspwm.1%{ext_man}
%{_mandir}/man1/bspc.1%{ext_man}
%{_datadir}/bash-completion/completions/bspc
%{_datadir}/fish/vendor_completions.d/bspc.fish
%{_datadir}/zsh/site-functions/_bspc
%{_datadir}/xsessions/bspwm.desktop
%{_sysconfdir}/skel/.config/bspwm
%config %{_sysconfdir}/skel/.config/bspwm/bspwmrc

%changelog
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Update to 0.9.2
- Changes
  * Monitors, desktops and nodes have unique IDs, `bspc query -{N,D,M}`
    returns IDs and events reference objects by ID instead of name.
  * `bspc` fails verbosely and only returns a single non-zero exit code.
  * The `DIR` descriptor is based on [right-window](https://github.com/ntrrgc/right-window).
  * The `CYCLE_DIR` descriptor isn't limited to the current
    desktop/monitor anymore. (You can emulate the previous behavior
    by appending a `.local` modifier to the selector.)
  * `bspc query -{N,D,M}` accepts an optional reference argument
    used by certain descriptors/modifiers.
  * Monitors are ordered visually by default.
  * The following settings: `border_width`, `window_gap` and
    `*_padding` behave as expected.
  * External rules also receives the monitor, desktop and node
    selectors computed from the built-in rules stage as subsequent arguments.
  * The `focus_follows_pointer` setting is implemented via enter
    notify events.
- Additions
  * Nodes can be hidden/shown via the new `hidden` flag.
  * Node receptacles can be inserted with `node -i`. An example
    is given in `git show e8aa679`.
  * Non-tiled nodes can be moved/resized via `node -{v,z}`.
  * The reference of a selector can be set via the `{NODE,DESKTOP
    ,MONITOR}_SEL#` prefix, example: `bspc node 0x0080000c#south -c`
    will close the node at the south of `0x0080000c`.
  * Node descriptors: `<node_id>`, `pointed`.
  * Node modifiers: `hidden`, `descendant_of`, `ancestor_of`, `window`,
    `active`. Example: `bspc query -N 0x00400006 -n .descendant_of` returns
    the descendants of `0x00400006`.
  * Desktop descriptor: `<desktop_id>`.
  * Monitor descriptor: `<monitor_id>`.
  * Settings: `pointer_motion_interval`, `pointer_modifier`,
    `pointer_action{1,2,3}`, `click_to_focus`, `honor_size_hints`.
  * Event: `pointer_action`.
  * ICCCM/EWMH atoms: `WM_STATE`, `_NET_WM_STRUT_PARTIAL`.
  * `bspc` shell completions for `fish`.
- Removals
  * The `pointer` domain. Pointer actions are handled internally.
    You need to remove any binding that uses this domain from your
    `sxhkdrc`.
  * Settings: `history_aware_focus`, `focus_by_distance`. Both
    settings are merged into the new `DIR` implementation.
  * `monitor -r|--remove-desktops`: use `desktop -r|--remove` instead.
  * `wm -r|--remove-monitor`: use `monitor -r|--remove` instead.
* Wed Oct  5 2016 luke.nukem.jones@gmail.com
- change sxhkd and dmenu to be recommended, not required
- move to pkgconfig deps, add desktop-utils handling
* Fri Jul 15 2016 luke.nukem.jones@gmail.com
- Initial packaging of bspwm
